@@ -75,3 +75,27 @@ is.in.ring <- function(atom) {
   flag.idx <- .jfield("org/openscience/cdk/CDKConstants", "I", "ISINRING")
   .jcall(atom, "Z", "getFlag", as.integer(flag.idx))
 }
+
+get.connected.atoms <- function(atom, mol) {
+  if (is.null(attr(mol, 'jclass')))
+    stop("object must be of class IAtomContainer")
+  
+  if (attr(mol, 'jclass') != "org/openscience/cdk/interfaces/IAtomContainer")
+    stop("object must be of class IAtomContainer")
+  
+  atom <- .valid.atom(atom)
+  ret <- .jcall(mol, "Ljava/util/List;", "getConnectedAtomsList", atom)
+  ret <- lapply(.javalist.to.rlist(ret), .jcast, new.class='org/openscience/cdk/interfaces/IAtom')
+  return(ret)
+}
+
+get.atom.index <- function(atom, mol) {
+  if (is.null(attr(mol, 'jclass')))
+    stop("object must be of class IAtomContainer")
+  
+  if (attr(mol, 'jclass') != "org/openscience/cdk/interfaces/IAtomContainer")
+    stop("object must be of class IAtomContainer")
+  
+  atom <- .valid.atom(atom)
+  .jcall(mol, "I", "getAtomNumber", atom)
+}
