@@ -21,6 +21,26 @@ test.match3 <- function()
   checkEquals(2, length(matches(q,list(m1,m2))))
 }
 
+test.match4 <- function()
+{
+
+  smiles <- c('CCC', 'c1ccccc1', 'C(C)(C=O)C(CCNC)C1CC1C(=O)')
+  mols <- sapply(smiles, parse.smiles)
+  mappings <- matches("CCCC", mols, TRUE)
+  checkEquals(3, length(mappings))
+  checkTrue(!mappings[[1]]$match)
+  checkTrue(!mappings[[2]]$match)
+  checkTrue(mappings[[3]]$match)
+
+  checkTrue(is.null(mappings[[1]]$mapping))
+  checkTrue(is.null(mappings[[2]]$mapping))
+
+  checkEquals(13, length(mappings[[3]]$mapping))
+  m <- sapply(mappings[[3]]$mapping, function(x) length(x))
+  checkTrue(all(m == 4))
+}
+
+
 test.mcs1 <- function() {
   mols <- parse.smiles(c("NCc1ccccc1OC(=N)CCN", "c1ccccc1OC(=N)"))
   lapply(mols, do.aromaticity)
